import TransportStream from 'winston-transport';
import { LoggingPlugin } from '../loggingPlugin';
import { LogLevel } from '../logLevel';
import { LogMessage, LogMessageMeta, LogMessageObject } from '../logMessage';
/**
 * A Logging Plugin that uses Winston to log messages
 */
export declare class WinstonPlugin implements LoggingPlugin {
    private _logger;
    /**
     * @param transports - an array of transport instances. Instance classes must extend the TransportStream class.
     * @defaultValue `[new ConsoleTransport()]`
     */
    constructor(transports?: TransportStream[]);
    /**
     * Sets the Winston logger maximum log level
     *
     * @param level - the maximum log level
     */
    setMaxLogLevel(level: LogLevel): void;
    /**
     * Sets the Winston default metadata
     *
     * @param metadata - default metadata to include in each log message
     */
    setDefaultMetadata(metadata: LogMessageObject): void;
    /**
     * Logs the message using the Winston logger
     *
     * @param level - the log level of the log message
     * @param message - the primary message to be logged
     */
    log(level: LogLevel, message: LogMessage): void;
    /**
     * Logs the message using the Winston logger
     *
     * @param level - the log level of the log message
     * @param message - the primary message to be logged
     * @param meta - any other data to be logged
     */
    log(level: LogLevel, message: string, meta: LogMessageMeta): void;
}
//# sourceMappingURL=winstonPlugin.d.ts.map