"use strict";
/*
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *  SPDX-License-Identifier: Apache-2.0
 */
Object.defineProperty(exports, "__esModule", { value: true });
exports.WinstonPlugin = void 0;
const winston_1 = require("winston");
const consoleTransport_1 = require("./winstonTransports/consoleTransport");
/**
 * A Logging Plugin that uses Winston to log messages
 */
class WinstonPlugin {
    /**
     * @param transports - an array of transport instances. Instance classes must extend the TransportStream class.
     * @defaultValue `[new ConsoleTransport()]`
     */
    constructor(transports = [new consoleTransport_1.ConsoleTransport()]) {
        this._logger = (0, winston_1.createLogger)({
            format: winston_1.format.combine(winston_1.format.errors({ stack: true }), winston_1.format.json()),
            transports
        });
    }
    /**
     * Sets the Winston logger maximum log level
     *
     * @param level - the maximum log level
     */
    setMaxLogLevel(level) {
        this._logger.level = level;
    }
    /**
     * Sets the Winston default metadata
     *
     * @param metadata - default metadata to include in each log message
     */
    setDefaultMetadata(metadata) {
        this._logger.defaultMeta = { meta: metadata };
    }
    // eslint-disable-next-line @typescript-eslint/no-explicit-any
    log(level, message, meta) {
        if (meta) {
            this._logger.log(level, message, meta);
        }
        else {
            if (typeof message === 'object') {
                this._logger.log(level, { message });
            }
            else {
                this._logger.log(level, message);
            }
        }
    }
}
exports.WinstonPlugin = WinstonPlugin;
//# sourceMappingURL=winstonPlugin.js.map