import { LEVEL, MESSAGE } from 'triple-beam';
import TransportStream from 'winston-transport';
import { LogLevel } from '../../logLevel';
/**
 * A LoggerInfo interface that contains the information logged by the ConsoleTransport log() method.
 */
interface LoggerInfo {
    /**
     * The [MESSAGE] parameter generated by a Winston "finalizing format":
     * - json
     * - logstash
     * - printf
     * - prettyPrint
     * - simple
     */
    [MESSAGE]: string;
    /**
     * The [LEVEL] parameter generated by Winston
     */
    [LEVEL]: LogLevel;
}
/**
 * A direct to console transport for use by the Winston logger.
 *
 * This transport assumes that the winston logger is formatted by one of Winston's "finalizing formats":
 * - json
 * - logstash
 * - printf
 * - prettyPrint
 * - simple
 */
export declare class ConsoleTransport extends TransportStream {
    /**
     * This method from a Winston logger to pass the log message from the logger to the transport
     *
     * @param info - the {@link LoggerInfo} object passed from Winston
     * @param callback - an optional callback passed from Winston
     */
    log(info: LoggerInfo, callback?: () => void): void;
}
export {};
//# sourceMappingURL=consoleTransport.d.ts.map