"use strict";
/*
 *  Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 *  SPDX-License-Identifier: Apache-2.0
 */
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConsoleTransport = void 0;
const triple_beam_1 = require("triple-beam");
const winston_transport_1 = __importDefault(require("winston-transport"));
/**
 * A direct to console transport for use by the Winston logger.
 *
 * This transport assumes that the winston logger is formatted by one of Winston's "finalizing formats":
 * - json
 * - logstash
 * - printf
 * - prettyPrint
 * - simple
 */
class ConsoleTransport extends winston_transport_1.default {
    /**
     * This method from a Winston logger to pass the log message from the logger to the transport
     *
     * @param info - the {@link LoggerInfo} object passed from Winston
     * @param callback - an optional callback passed from Winston
     */
    log(info, callback) {
        /* istanbul ignore next */
        setImmediate(() => this.emit('logged', info));
        // Use console here so request ID and log level can be automatically attached in CloudWatch log
        // info[LEVEL] and info[MESSAGE] break the eslint and semgrep rules below
        // but are where Winston stores the level and message properties, so the rule must be turned off for this section
        /* eslint-disable security/detect-object-injection */
        switch (info[triple_beam_1.LEVEL] // nosemgrep
        ) {
            case 'debug':
                console.debug(info[triple_beam_1.MESSAGE]); // nosemgrep
                break;
            case 'info':
                console.info(info[triple_beam_1.MESSAGE]); // nosemgrep
                break;
            case 'warn':
                console.warn(info[triple_beam_1.MESSAGE]); // nosemgrep
                break;
            case 'error':
                console.error(info[triple_beam_1.MESSAGE]); // nosemgrep
                break;
            default:
                console.log(info[triple_beam_1.MESSAGE]); // nosemgrep
                break;
        }
        /* eslint-enable security/detect-object-injection */
        if (callback) {
            callback();
        }
    }
}
exports.ConsoleTransport = ConsoleTransport;
//# sourceMappingURL=consoleTransport.js.map